Index: test/unittests/interpreter/bytecode-array-builder-unittest.cc |
diff --git a/test/unittests/interpreter/bytecode-array-builder-unittest.cc b/test/unittests/interpreter/bytecode-array-builder-unittest.cc |
index e5883b8836dc596295ff7bd3b87495f76cb3716f..7c157d3b76759ec384f22ad31efd125f7afd3a88 100644 |
--- a/test/unittests/interpreter/bytecode-array-builder-unittest.cc |
+++ b/test/unittests/interpreter/bytecode-array-builder-unittest.cc |
@@ -40,8 +40,12 @@ TEST_F(BytecodeArrayBuilderTest, AllBytecodesGenerated) { |
Register reg(0); |
builder.LoadAccumulatorWithRegister(reg).StoreAccumulatorInRegister(reg); |
// Emit global load operations. |
builder.LoadGlobal(1); |
+ builder.StoreGlobal(1, LanguageMode::SLOPPY); |
+ |
+ // Emit context load operations. |
+ builder.LoadContextSlot(reg, 1); |
// Emit load / store property operations. |
builder.LoadNamedProperty(reg, 0, LanguageMode::SLOPPY) |
@@ -40,8 +40,12 @@ TEST_F(BytecodeArrayBuilderTest, AllBytecodesGenerated) { |
Register reg(0); |
builder.LoadAccumulatorWithRegister(reg).StoreAccumulatorInRegister(reg); |
- // Emit global load operations. |
+ // Emit global load / store operations. |
builder.LoadGlobal(1); |